@@ -372,7 +372,7 @@ gnome_print_dialog_construct (GnomePrintDialog *gpd, const guchar *title, gint f
 		l = gtk_label_new_with_mnemonic (_("Printer"));
 		gtk_widget_show (l);
 		
-		gtk_notebook_append_page (GTK_NOTEBOOK (gpd->notebook), hb, l);
+		gtk_notebook_prepend_page (GTK_NOTEBOOK (gpd->notebook), hb, l);
 		
 		/* Add a paper page */
 		p = gnome_paper_selector_new (gpd->config);
