@@ -44,10 +44,10 @@ typedef struct _GnomePaperSelectorClass GnomePaperSelectorClass;
 #include <glib-object.h>
 #include <libgnomeprint/gnome-print-config.h>
 
-enum GnomePaperSelectorFlags {
+typedef enum {
 	GNOME_PAPER_SELECTOR_MARGINS = (1 << 0),
 	GNOME_PAPER_SELECTOR_FEED_ORIENTATION = (1 << 1)
-};
+} GnomePaperSelectorFlags;
 
 GType       gnome_paper_selector_get_type (void);
 GtkWidget * gnome_paper_selector_new (GnomePrintConfig *config);
