@@ -325,12 +325,6 @@ gpp_glyphlist (GnomePrintContext *pc, const gdouble *affine, GnomeGlyphList * gl
 	GnomeCanvasItem *item;
 	double transform[6], a[6];
 
-	/*
-	 * The X and Y positions were computed to be the base
-	 * with the translation already done for the new
-	 * Postscript->Canvas translation
-	 */
-	memcpy (transform, gp_gc_get_ctm (pc->gc), sizeof (transform));
 	art_affine_scale (a, 1.0, -1.0);
 	art_affine_multiply (transform, a, affine);
 
